==> root_v4.02.00.source.tar.gz: root/geom/inc/LinkDef1.h <==
// @(#)root/geom:$Name:  $:$Id: LinkDef1.h,v 1.9 2004/11/25 12:10:00 brun Exp $
// Author : Andrei Gheata 10/06/02
/*************************************************************************
 * Copyright (C) 1995-2000, Rene Brun and Fons Rademakers.               *
 * All rights reserved.                                                  *
 *                                                                       *
 * For the licensing terms see $ROOTSYS/LICENSE.                         *
 * For the list of contributors see $ROOTSYS/README/CREDITS.             *
 *************************************************************************/

#ifdef __CINT__

#pragma link off all globals;
#pragma link off all classes;
#pragma link off all functions;

#pragma link C++ global gGeoManager;
#pragma link C++ global gGeoIdentity;

#pragma link C++ class TGeoAtt+;
#pragma link C++ class TGeoBoolNode+;
#pragma link C++ class TGeoUnion+;
#pragma link C++ class TGeoIntersection+;
#pragma link C++ class TGeoSubtraction+;
#pragma link C++ class TGeoMedium+;
#pragma link C++ class TGeoElement+;
#pragma link C++ class TGeoElementTable+;
#pragma link C++ class TGeoMaterial+;
#pragma link C++ class TGeoMixture+;
#pragma link C++ class TGeoMatrix+;
#pragma link C++ class TGeoHMatrix+;
#pragma link C++ class TGeoTranslation+;
#pragma link C++ class TGeoRotation+;
#pragma link C++ class TGeoCombiTrans+;
#pragma link C++ class TGeoGenTrans+;
#pragma link C++ class TGeoScale+;
#pragma link C++ class TGeoIdentity+;
#pragma link C++ class TGeoVoxelFinder+;
#pragma link C++ class TGeoCylVoxels+;
#pragma link C++ class TGeoFullVoxels+;
#pragma link C++ class TGeoShape+;
#pragma link C++ class TGeoHelix+;
#pragma link C++ class TGeoHalfSpace+;
#pragma link C++ class TGeoBBox+;
#pragma link C++ class TGeoPara+;
#pragma link C++ class TGeoSphere+;
#pragma link C++ class TGeoTube+;
#pragma link C++ class TGeoTorus+;
#pragma link C++ class TGeoTubeSeg+;
#pragma link C++ class TGeoCtub+;
#pragma link C++ class TGeoEltu+;
#pragma link C++ class TGeoHype+;
#pragma link C++ class TGeoCone+;
#pragma link C++ class TGeoConeSeg+;
#pragma link C++ class TGeoParaboloid+;
#pragma link C++ class TGeoPcon+;
#pragma link C++ class TGeoPgon+;
#pragma link C++ class TGeoArb8+;
#pragma link C++ class TGeoTrap+;
#pragma link C++ class TGeoGtra+;
#pragma link C++ class TGeoTrd1+;
#pragma link C++ class TGeoTrd2+;
#pragma link C++ class TGeoCompositeShape+;
#pragma link C++ class TGeoPolygon+;
#pragma link C++ class TGeoXtru+;
#pragma link C++ class TGeoVolume-;
#pragma link C++ class TGeoVolumeAssembly+;
#pragma link C++ class TGeoVolumeMulti+;
#pragma link C++ class TGeoNode+;
#pragma link C++ class TGeoPhysicalNode+;
#pragma link C++ class TGeoNodeMatrix+;
#pragma link C++ class TGeoNodeOffset+;
#pragma link C++ class TGeoManager-;
#pragma link C++ class TVirtualGeoPainter+;
#pragma link C++ class TVirtualGeoTrack+;


#endif

==> root_v5.02.00.source.tar.gz: root/geom/inc/LinkDef1.h <==
// @(#)root/geom:$Name:  $:$Id: LinkDef1.h,v 1.11 2005/06/13 12:17:31 brun Exp $
// Author : Andrei Gheata 10/06/02
/*************************************************************************
 * Copyright (C) 1995-2000, Rene Brun and Fons Rademakers.               *
 * All rights reserved.                                                  *
 *                                                                       *
 * For the licensing terms see $ROOTSYS/LICENSE.                         *
 * For the list of contributors see $ROOTSYS/README/CREDITS.             *
 *************************************************************************/

#ifdef __CINT__

#pragma link off all globals;
#pragma link off all classes;
#pragma link off all functions;

#pragma link C++ global gGeoManager;
#pragma link C++ global gGeoIdentity;

#pragma link C++ class TGeoAtt+;
#pragma link C++ class TGeoBoolNode+;
#pragma link C++ class TGeoUnion+;
#pragma link C++ class TGeoIntersection+;
#pragma link C++ class TGeoSubtraction+;
#pragma link C++ class TGeoMedium+;
#pragma link C++ class TGeoElement+;
#pragma link C++ class TGeoElementTable+;
#pragma link C++ class TGeoMaterial+;
#pragma link C++ class TGeoMixture+;
#pragma link C++ class TGeoMatrix+;
#pragma link C++ class TGeoHMatrix+;
#pragma link C++ class TGeoTranslation+;
#pragma link C++ class TGeoRotation+;
#pragma link C++ class TGeoCombiTrans+;
#pragma link C++ class TGeoGenTrans+;
#pragma link C++ class TGeoScale+;
#pragma link C++ class TGeoIdentity+;
#pragma link C++ class TGeoVoxelFinder+;
#pragma link C++ class TGeoCylVoxels+;
#pragma link C++ class TGeoFullVoxels+;
#pragma link C++ class TGeoShape+;
#pragma link C++ class TGeoHelix+;
#pragma link C++ class TGeoHalfSpace+;
#pragma link C++ class TGeoBBox+;
#pragma link C++ class TGeoPara+;
#pragma link C++ class TGeoSphere+;
#pragma link C++ class TGeoTube+;
#pragma link C++ class TGeoTorus+;
#pragma link C++ class TGeoTubeSeg+;
#pragma link C++ class TGeoCtub+;
#pragma link C++ class TGeoEltu+;
#pragma link C++ class TGeoHype+;
#pragma link C++ class TGeoCone+;
#pragma link C++ class TGeoConeSeg+;
#pragma link C++ class TGeoParaboloid+;
#pragma link C++ class TGeoPcon+;
#pragma link C++ class TGeoPgon+;
#pragma link C++ class TGeoArb8+;
#pragma link C++ class TGeoTrap+;
#pragma link C++ class TGeoGtra+;
#pragma link C++ class TGeoTrd1+;
#pragma link C++ class TGeoTrd2+;
#pragma link C++ class TGeoCompositeShape+;
#pragma link C++ class TGeoPolygon+;
#pragma link C++ class TGeoXtru-;
#pragma link C++ class TGeoShapeAssembly+;
#pragma link C++ class TGeoVolume-;
#pragma link C++ class TGeoVolumeAssembly+;
#pragma link C++ class TGeoVolumeMulti+;
#pragma link C++ class TGeoNode+;
#pragma link C++ class TGeoPhysicalNode+;
#pragma link C++ class TGeoNodeMatrix+;
#pragma link C++ class TGeoNodeOffset+;
#pragma link C++ class TGeoManager-;
#pragma link C++ class TVirtualGeoPainter+;
#pragma link C++ class TVirtualGeoTrack+;


#endif
